=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2013-05-23 08:10:58 +0000
+++ bzrlib/osutils.py	2013-05-23 08:25:07 +0000
@@ -2522,10 +2522,11 @@
 else:
     is_local_pid_dead = _posix_is_local_pid_dead
 
-_fdatasync_ignored = [getattr(errno, name)
-                      for name in ['EAGAIN', 'EINTR', 'ENOTSUP', 'EACCES']
+_maybe_ignored = ['EAGAIN', 'EINTR', 'ENOTSUP', 'EOPNOTSUPP', 'EACCES']
+_fdatasync_ignored = [getattr(errno, name) for name in _maybe_ignored
                       if getattr(errno, name, None) is not None]
 
+
 def fdatasync(fileno):
     """Flush file contents to disk if possible.
     

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2012-11-05 12:05:39 +0000
+++ bzrlib/tests/test_osutils.py	2013-05-23 08:25:07 +0000
@@ -435,6 +435,10 @@
         f.close()
 
     @staticmethod
+    def raise_eopnotsupp(*args, **kwargs):
+        raise IOError(errno.EOPNOTSUPP, os.strerror(errno.EOPNOTSUPP))
+
+    @staticmethod
     def raise_enotsup(*args, **kwargs):
         raise IOError(errno.ENOTSUP, os.strerror(errno.ENOTSUP))
 
@@ -447,8 +451,8 @@
         self.overrideAttr(os, "fsync")
         self.do_fdatasync()
 
-    def test_fdatasync_handles_no_ENOTSUP(self):
-        self.overrideAttr(errno, "ENOTSUP")
+    def test_fdatasync_handles_no_EOPNOTSUPP(self):
+        self.overrideAttr(errno, "EOPNOTSUPP")
         self.do_fdatasync()
 
     def test_fdatasync_catches_ENOTSUP(self):
@@ -458,6 +462,13 @@
         self.overrideAttr(os, "fdatasync", self.raise_enotsup)
         self.do_fdatasync()
 
+    def test_fdatasync_catches_EOPNOTSUPP(self):
+        enotsup = getattr(errno, "EOPNOTSUPP", None)
+        if enotsup is None:
+            raise tests.TestNotApplicable("No EOPNOTSUPP on this platform")
+        self.overrideAttr(os, "fdatasync", self.raise_eopnotsupp)
+        self.do_fdatasync()
+
 
 class TestLinks(tests.TestCaseInTempDir):
 

